@@ -5,7 +5,7 @@ from racetrack_client.client_config.client_config import ClientConfig
 
 
 DEFAULT_LIFECYCLE_SCHEME = 'https'
-DEFAULT_LIFECYCLE_PATH = '/ikp-rt/lifecycle'
+DEFAULT_LIFECYCLE_PATH = '/lifecycle'
 
 
 def resolve_lifecycle_url(client_config: ClientConfig, lifecycle_name: Optional[str]) -> str:
@@ -29,6 +29,8 @@ def _resolve_short_lifecycle_url(client_config: ClientConfig, lifecycle_name: Op
 def _infer_full_lifecycle_url(url: str) -> str:
     """Apply default protocol and path if not provided."""
     split = urlsplit(url)
+    if split.netloc == '':
+        split = split._replace(scheme='', netloc=split.scheme)
     if not split.scheme:
         url = f'{DEFAULT_LIFECYCLE_SCHEME}://{url}'
     split = urlsplit(url)  # parse again as path is recognized properly only with a scheme
