@@ -1,7 +1,5 @@
-import dataclasses
 from typing import Dict
 
-import dacite
 from racetrack_client.log.context_error import wrap_context
 from racetrack_client.client_config.io import load_client_config, save_client_config
 from racetrack_client.client_config.client_config import Credentials, ClientConfig
@@ -21,16 +19,12 @@ def set_credentials(repo_url: str, username: str, token_password: str):
 
 def set_config_setting(setting_name: str, setting_value: str):
     client_config = load_client_config()
-    config_dict: Dict = dataclasses.asdict(client_config)
+    config_dict = client_config.dict()
 
     assert setting_name in config_dict, f'client config doesn\'t have setting named {setting_name}'
     config_dict[setting_name] = setting_value
     with wrap_context('converting setting to target data type'):
-        client_config = dacite.from_dict(
-            data_class=ClientConfig,
-            data=config_dict,
-            config=dacite.Config(cast=[]),
-        )
+        client_config = ClientConfig.parse_obj(config_dict)
 
     logger.info(f'Client setting {setting_name} set to: {setting_value}')
     save_client_config(client_config)
