@@ -14,13 +14,13 @@ def short_exception_logger(exc_info, *_):
     """
     try:
         ex_type, e, tb = exc_info
-        log_message = _get_exc_info_details(ex_type, e, tb)
+        log_message = get_exc_info_details(ex_type, e, tb)
         logger.error(log_message)
     except BaseException as e:
         logger.exception(e)
 
 
-def _get_exc_info_details(ex_type, e, tb) -> str:
+def get_exc_info_details(ex_type, e, tb) -> str:
     """
     Return concise one-line details of exception, containing message, traceback and root cause type
     :param ex_type: Exception type
@@ -52,7 +52,7 @@ def short_exception_details(e: BaseException) -> str:
     """
     Return concise one-line details of exception, containing message, traceback and root cause type
     """
-    return _get_exc_info_details(type(e), e, e.__traceback__)
+    return get_exc_info_details(type(e), e, e.__traceback__)
 
 
 def _get_traceback_lines(t1: traceback.TracebackException) -> Iterable[str]:
