@@ -1,9 +1,59 @@
-from dataclasses import dataclass
 from typing import Optional, List, Dict, Any
 
+from pydantic import BaseModel, Extra, validator
 
-@dataclass
-class Manifest:
+from racetrack_client.utils.quantity import Quantity
+
+
+class PythonManifest(BaseModel, extra=Extra.forbid):
+    requirements_path: Optional[str] = None
+    # path to a Python file with a entrypoint class
+    entrypoint_path: str = ''
+    # base name of Python entrypoint class
+    entrypoint_class: str = ''
+
+
+class GoManifest(BaseModel, extra=Extra.forbid):
+    # relative path to Go modules requirements
+    gomod: str = 'go.mod'
+
+
+class GitManifest(BaseModel, extra=Extra.forbid):
+    # URL of git remote: HTTPS, SSH or directory path to a remote repository
+    remote: str
+    branch: Optional[str] = None
+    # subdirectory relative to git repo root
+    directory: str = '.'
+
+
+class DockerManifest(BaseModel, extra=Extra.forbid):
+    dockerfile_path: Optional[str] = None
+
+
+class ResourcesManifest(BaseModel, extra=Extra.forbid, arbitrary_types_allowed=True):
+    # minimum memory amount in bytes, eg. 100Mi
+    memory_min: Optional[Quantity] = None
+    # maximum memory amount in bytes, eg. 4Gi
+    memory_max: Optional[Quantity] = None
+    # minimum CPU consumption in cores, eg. 10m
+    cpu_min: Optional[Quantity] = None
+    # maximum CPU consumption in cores, eg. 1000m
+    cpu_max: Optional[Quantity] = None
+
+
+    @validator(
+        'memory_min', 
+        'memory_max', 
+        'cpu_min',
+        'cpu_max',
+        pre=True)
+    def _validate_quantity(cls, v):
+        if v is None:
+            return None
+        return Quantity(str(v))
+
+
+class Manifest(BaseModel, extra=Extra.forbid):
     """Fatman Manifest file - build recipe to get deployable image from source code workspace"""
 
     # name of the Fatman Workload
@@ -12,7 +62,7 @@ class Manifest:
     # email address of the Fatman's owner to reach out
     owner_email: str
 
-    git: 'GitManifest'
+    git: GitManifest
 
     # version of the Fatman
     version: str = '0.0.1'
@@ -20,14 +70,17 @@ class Manifest:
     # Language wrapper used to embed model
     lang: str = 'python3'
 
+    # relative path to base manifest file, which will be extended by this manifest
+    extends: Optional[str] = None
+
     # Python-specific configuration
-    python: Optional['PythonManifest'] = None
+    python: Optional[PythonManifest] = None
 
     # Go/Golang-specific configuration
-    golang: Optional['GoManifest'] = None
+    golang: Optional[GoManifest] = None
 
     # Docker-specific configuration
-    docker: Optional['DockerManifest'] = None
+    docker: Optional[DockerManifest] = None
 
     # type of deployed image: docker image, packer, AMI
     image_type: str = 'docker'
@@ -53,31 +106,8 @@ class Manifest:
     # number of instances of the Fatman
     replicas: int = 1
 
+    # resources demands to allocate to the Fatman
+    resources: Optional[ResourcesManifest] = None
 
-@dataclass
-class PythonManifest:
-    requirements_path: Optional[str] = None
-    # path to a Python file with a entrypoint class
-    entrypoint_path: str = ''
-    # base name of Python entrypoint class
-    entrypoint_class: str = ''
-
-
-@dataclass
-class GoManifest:
-    # relative path to Go modules requirements
-    gomod: str = 'go.mod'
-
-
-@dataclass
-class GitManifest:
-    # URL of git remote: HTTPS, SSH or directory path to a remote repository
-    remote: str
-    branch: Optional[str] = None
-    # subdirectory relative to git repo root
-    directory: str = '.'
-
-
-@dataclass
-class DockerManifest:
-    dockerfile_path: Optional[str] = None
+    # Language wrapper attributes
+    wrapper_properties: Optional[Dict[str, Any]] = None
