@@ -4,8 +4,10 @@ from urllib.parse import urlsplit
 
 from racetrack_client.log.context_error import wrap_context
 from racetrack_client.manifest import Manifest
-from racetrack_client.manifest.load import FATMAN_MANIFEST_FILENAME, load_manifest_from_yaml
+from racetrack_client.manifest.load import get_manifest_path
 from racetrack_client.log.logs import get_logger
+from racetrack_client.manifest.merge import load_merged_manifest
+from racetrack_client.utils.datamodel import datamodel_to_yaml_str
 from racetrack_client.utils.semver import SemanticVersion
 
 logger = get_logger(__name__)
@@ -17,12 +19,9 @@ def load_validated_manifest(path: str) -> Manifest:
     :param path path to a Fatman manifest file or to a directory with it
     :return loaded, valid Manifest
     """
-    manifest_path = Path(path)
-    if manifest_path.is_dir():
-        manifest_path = manifest_path / FATMAN_MANIFEST_FILENAME
+    manifest_path = get_manifest_path(path)
+    manifest = load_merged_manifest(manifest_path)
 
-    with wrap_context('loading manifest'):
-        manifest = load_manifest_from_yaml(manifest_path)
     with wrap_context('validating manifest'):
         validate_manifest(manifest)
 
@@ -36,8 +35,6 @@ def validate_manifest(manifest: Manifest):
         assert manifest.python is None, f'"python" configuration should be filled only for python jobs'
     if manifest.lang != 'golang':
         assert manifest.golang is None, f'"golang" configuration should be filled only for golang jobs'
-    if manifest.lang != 'docker-http':
-        assert manifest.docker is None, f'"docker" configuration should be filled only for docker-http jobs'
 
     assert re.match(r"[^@]+@[^@]+\.[^@]+", manifest.owner_email), '"owner_email" is not a valid email'
 
@@ -47,3 +44,9 @@ def validate_manifest(manifest: Manifest):
     assert 1 <= manifest.replicas <= 15, 'replicas count out of allowed range'
 
     assert urlsplit(manifest.git.remote).scheme == 'https', 'git remote URL should be HTTPS'
+
+
+def validate_and_show_manifest(path: str):
+    manifest = load_validated_manifest(path)
+    logger.info(f'Manifest file "{path}" is valid')
+    print(datamodel_to_yaml_str(manifest))
